==> apache-camel-2.21.3-src.zip: apache-camel-2.21.3/components/camel-coap/src/test/java/org/apache/camel/coap/CoAPConsumerDefaultPortTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.coap;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit4.CamelTestSupport;
import org.eclipse.californium.core.CoapClient;
import org.eclipse.californium.core.CoapResponse;
import org.eclipse.californium.core.network.config.NetworkConfig;
import org.junit.Test;

public class CoAPConsumerDefaultPortTest extends CamelTestSupport {

    @Test
    public void testCoAPConsumerWithDefaultPort() throws Exception {
        NetworkConfig.createStandardWithoutFile();

        CoapClient client = new CoapClient("coap://localhost:" + CoAPComponent.DEFAULT_PORT + "/greeting");
        CoapResponse response = client.get();

        assertEquals("Hello World", response.getResponseText());
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("coap:localhost/greeting")
                    .setBody(constant("Hello World"));
            }
        };
    }
}

==> apache-camel-2.23.4-src.zip: apache-camel-2.23.4/components/camel-coap/src/test/java/org/apache/camel/coap/CoAPConsumerDefaultPortTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.coap;

import org.apache.camel.builder.RouteBuilder;
import org.eclipse.californium.core.CoapClient;
import org.eclipse.californium.core.CoapResponse;
import org.junit.Test;

public class CoAPConsumerDefaultPortTest extends CoAPTestSupport {

    @Test
    public void testCoAPConsumerWithDefaultPort() throws Exception {
        CoapClient client = createClient("/greeting", CoAPComponent.DEFAULT_PORT);
        CoapResponse response = client.get();
        assertEquals("Hello World", response.getResponseText());
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("coap:localhost/greeting")
                    .setBody(constant("Hello World"));
            }
        };
    }
}
